Date: 01 4, 2002 1:20:29 PM

# findnode

## Purpose

Find a node in a phrase. There are two variants: to find a node in a phrase aPhrase by the node's name nameString and to find a node in a phrase aPhrase by node number positionNum.

## Syntax

returnedConcept = findnode(aPhrase, nameString);

returnedConcept - type: con
aPhrase - type: phr
nameString - type: str

returnedConcept = findnode(aPhrase, positionNum);

returnedConcept - type: con
aPhrase - type: phr
positionNum - type: int

## Returns

## Remarks

## Example

## See Also

firstnode, lastnode, listnode, Knowledge Base Functions